<?php

namespace AppBundle\Controller;

use AppBundle\Entity\TCarrera;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;

use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Response;

use Symfony\Component\HttpFoundation\Request;

/**
 * Tcarrera controller.
 *
 * @Route("tcarrera")
 */
class TCarreraController extends Controller
{
    /**
     * Lists all tCarrera entities.
     *
     * @Route("/", name="tcarrera_index")
     * @Method("GET")
     */
    public function indexAction()
    {
        $em = $this->getDoctrine()->getManager();

        $tCarreras = $em->getRepository('AppBundle:TCarrera')->findAll();

	    $deleteFormAjax = $this->createCustomForm(':USER_ID', 'DELETE', 'tcarrera_delete');
        return $this->render('tcarrera/index.html.twig', array(
            'tCarreras' => $tCarreras,
            'delete_form_ajax' => $deleteFormAjax->createView(),
        ));
    }

    /**
     * Creates a new tCarrera entity.
     *
     * @Route("/new", name="tcarrera_new")
     * @Method({"GET", "POST"})
     */
    public function newAction(Request $request)
    {
        $tCarrera = new Tcarrera();
        $form = $this->createForm('AppBundle\Form\TCarreraType', $tCarrera);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($tCarrera);
            $em->flush();

	        $this->addFlash( 'mensaje', 'Se agregó la carrera exitósamente.' );
            return $this->redirectToRoute('tcarrera_index');
        }

        return $this->render('tcarrera/new.html.twig', array(
            'tCarrera' => $tCarrera,
            'form' => $form->createView(),
        ));
    }

    /**
     * Finds and displays a tCarrera entity.
     *
     * @Route("/{idCarrera}", name="tcarrera_show")
     * @Method("GET")
     */
    public function showAction(TCarrera $tCarrera)
    {
        $deleteForm = $this->createDeleteForm($tCarrera);

        return $this->render('tcarrera/show.html.twig', array(
            'tCarrera' => $tCarrera,
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Displays a form to edit an existing tCarrera entity.
     *
     * @Route("/{idCarrera}/edit", name="tcarrera_edit")
     * @Method({"GET", "POST"})
     */
    public function editAction(Request $request, TCarrera $tCarrera)
    {

        $editForm = $this->createForm('AppBundle\Form\TCarreraType', $tCarrera);
        $editForm->handleRequest($request);

        if ($editForm->isSubmitted() && $editForm->isValid()) {
            $this->getDoctrine()->getManager()->flush();

	        $this->addFlash( 'mensaje', 'Se modificó la carrera exitósamente.' );
            return $this->redirectToRoute('tcarrera_index');
        }

        return $this->render('tcarrera/edit.html.twig', array(
            'tCarrera' => $tCarrera,
            'form' => $editForm->createView()
        ));
    }

    /**
     * Creates a form to delete a tCarrera entity.
     *
     * @param TCarrera $tCarrera The tCarrera entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(TCarrera $tCarrera)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('tcarrera_delete', array('idCarrera' => $tCarrera->getIdcarrera())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }

	private function createCustomForm($id, $method, $route)
	{
		return $this->createFormBuilder()
		            ->setAction($this->generateUrl($route, array('id'=>$id)))
		            ->setMethod($method)
		            ->getForm();
	}

	private function deleteRegistro($em, $tCarrera)
	{

		$em->remove($tCarrera);
		$em->flush();

		$message = 'La carrera ha sido eliminado exitósamente';

		$removed = 1;
		$alert = 'mensaje';


		return array('removed'=>$removed, 'message'=>$message, 'alert'=>$alert);
	}

	/**
	 * @Route("/borrar/{id}", name="tcarrera_delete")
	 */
	public function deleteAction(Request $request, TCarrera $tCarrera)
	{
		//$form = $this->createDeleteForm($tCarrera);
		$form = $this->createCustomForm($tCarrera->getIdCarrera(), 'DELETE', 'tcarrera_delete');
		$form->handleRequest($request);
		$em = $this->getDoctrine()->getManager();

		if ($form->isSubmitted() && $form->isValid()) {

			if($request->isXMLHttpRequest())
			{
				$res = $this->deleteRegistro($em, $tCarrera);

				return new Response(
					json_encode(array('removed'=>$res['removed'], 'message'=>$res['message'], )),
					200,
					array('Content-Type'=>'application/json')
				);
			}

			$res = $this->deleteRegistro($em, $tCarrera);

			$this->addFlash($res['alert'], $res['message']);

			return $this->redirectToRoute('tcarrera_index');
		}
	}
}
