<?php

namespace AppBundle\Controller;

use AppBundle\Entity\TCurso;
use AppBundle\Entity\TEvaluacion;
use AppBundle\Entity\TRespuesta;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;

use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Validator\Constraints\DateTime;
use Symfony\Component\HttpFoundation\Request;

/**
 * Tcurso controller.
 *
 * @Route("tcurso")
 */
class TCursoController extends Controller
{
    /**
     * Lists all tCurso entities.
     *
     * @Route("/", name="tcurso_index")
     * @Method("GET")
     */
    public function indexAction()
    {
        $em = $this->getDoctrine()->getManager();

        $tCursos = $em->getRepository('AppBundle:TCurso')->findAll();

        $deleteFormAjax = $this->createCustomForm(':USER_ID', 'DELETE', 'tcurso_delete');

        return $this->render('tcurso/index.html.twig', array(
            'tCursos' => $tCursos,
            'delete_form_ajax' => $deleteFormAjax->createView(),
        ));
    }

    /**
     * Creates a new tCurso entity.
     *
     * @Route("/new", name="tcurso_new")
     * @Method({"GET", "POST"})
     */
    public function newAction(Request $request)
    {
        $tCurso = new Tcurso();
        $form = $this->createForm('AppBundle\Form\TCursoType', $tCurso);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($tCurso);
            $em->flush();

	        $this->addFlash( 'mensaje', 'Se agregó el curso exitósamente.' );
            return $this->redirectToRoute('tcurso_index');
        }

        return $this->render('tcurso/new.html.twig', array(
            'tCurso' => $tCurso,
            'form' => $form->createView(),
        ));
    }

    /**
     * Finds and displays a tCurso entity.
     *
     * @Route("/{idCurso}", name="tcurso_show")
     * @Method("GET")
     */
    public function showAction(TCurso $tCurso)
    {
        return $this->render('tcurso/show.html.twig', array(
            'tCurso' => $tCurso,
        ));
    }

	/**
	 * Displays a form to edit an existing tPeriodo entity.
	 *
	 * @Route("/{idCurso}/edit", name="tcurso_edit")
	 * @Method({"GET", "POST"})
	 */
	public function editAction(Request $request, TCurso $tCurso)
	{
//        $deleteForm = $this->createDeleteForm($tCurso);
		$editForm = $this->createForm('AppBundle\Form\TCursoType', $tCurso);
		$editForm->handleRequest($request);

		if ($editForm->isSubmitted() && $editForm->isValid()) {
			$this->getDoctrine()->getManager()->flush();

			$this->addFlash('mensaje', 'Se modificó datos del curso exitósamente.');
			return $this->redirectToRoute('tcurso_index');
		}

		return $this->render('tcurso/edit.html.twig', array(
			'tCurso' => $tCurso,
			'form' => $editForm->createView(),
		));
	}
    











    
    /**
     * Creates a form to delete a tCurso entity.
     *
     * @param TCurso $tCurso The tCurso entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(TCurso $tCurso)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('tcurso_delete', array('idCurso' => $tCurso->getIdcurso())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }

	private function createCustomForm($id, $method, $route)
	{
		return $this->createFormBuilder()
		            ->setAction($this->generateUrl($route, array('id'=>$id)))
		            ->setMethod($method)
		            ->getForm();
	}

	private function deleteRegistro($em, $tCurso)
	{

		$em->remove($tCurso);
		$em->flush();

		$message = 'El curso ha sido eliminado exitósamente';

		$removed = 1;
		$alert = 'mensaje';


		return array('removed'=>$removed, 'message'=>$message, 'alert'=>$alert);
	}
	
	/**
	 * @Route("/borrar/{id}", name="tcurso_delete")
	 */
	public function deleteAction(Request $request, TCurso $tCurso)
	{
		//$form = $this->createDeleteForm($tCurso);
		$form = $this->createCustomForm($tCurso->getIdCurso(), 'DELETE', 'tcurso_delete');
		$form->handleRequest($request);
		$em = $this->getDoctrine()->getManager();

		if ($form->isSubmitted() && $form->isValid()) {

			if($request->isXMLHttpRequest())
			{
				$res = $this->deleteRegistro($em, $tCurso);

				return new Response(
					json_encode(array('removed'=>$res['removed'], 'message'=>$res['message'], )),
					200,
					array('Content-Type'=>'application/json')
				);
			}

			$res = $this->deleteRegistro($em, $tCurso);

			$this->addFlash($res['alert'], $res['message']);

			return $this->redirectToRoute('tcurso_index');
		}
	}
}
