<?php

namespace AppBundle\Controller;

use AppBundle\Entity\TEvaluacion;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\Request;

/**
 * Tevaluacion controller.
 *
 * @Route("tevaluacion")
 */
class TEvaluacionController extends Controller
{
    /**
     * Lists all tEvaluacion entities.
     *
     * @Route("/", name="tevaluacion_index")
     * @Method("GET")
     */
    public function indexAction()
    {
        $em = $this->getDoctrine()->getManager();

        $em = $this->getDoctrine()->getManager();
        $usuario = $this->getUser();
        $tEvaluacions = $em->getRepository('AppBundle:TUsuario')->findCursosProfeEvaluar(1, $usuario);
//var_dump($tEvaluacions); exit();

        $deleteFormAjax = $this->createCustomForm(':USER_ID', 'DELETE', 'tevaluacion_delete');

        return $this->render('tevaluacion/index.html.twig', array(
            'tEvaluacions' => $tEvaluacions,
            'delete_form_ajax' => $deleteFormAjax->createView(),
        ));
    }

    /**
     * Creates a new tEvaluacion entity.
     *
     * @Route("/{idCurso}/new", name="tevaluacion_new")
     * @Method({"GET", "POST"})
     */
    public function newAction(Request $request, $idCurso)
    {
        $tEvaluacion = new Tevaluacion();
        $form = $this->createForm('AppBundle\Form\TEvaluacionType', $tEvaluacion);
        $form->handleRequest($request);

        date_default_timezone_set('America/La_Paz');
        $fecha = new \DateTime("now");

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $tEvaluacion->setIdCurso($em->getRepository('AppBundle:TCurso')->find($idCurso));
            $tEvaluacion->setFechaCreacion($fecha);

            $em->persist($tEvaluacion);
            $em->flush();

            $this->addFlash('mensaje', 'Se agregó la evaluación exitósamente.');

            return $this->redirectToRoute('tevaluacion_index');
        }

        return $this->render('tevaluacion/new.html.twig', array(
            'tEvaluacion' => $tEvaluacion,
            'form' => $form->createView(),
        ));
    }

    /**
     * Finds and displays a tEvaluacion entity.
     *
     * @Route("/{idEvaluacion}", name="tevaluacion_show")
     * @Method("GET")
     */
    public function showAction(TEvaluacion $tEvaluacion)
    {
        $deleteForm = $this->createDeleteForm($tEvaluacion);

        return $this->render('tevaluacion/show.html.twig', array(
            'tEvaluacion' => $tEvaluacion,
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Displays a form to edit an existing tEvaluacion entity.
     *
     * @Route("/{idEvaluacion}/edit", name="tevaluacion_edit")
     * @Method({"GET", "POST"})
     */
    public function editAction(Request $request, TEvaluacion $tEvaluacion)
    {
        $deleteForm = $this->createDeleteForm($tEvaluacion);
        $editForm = $this->createForm('AppBundle\Form\TEvaluacionType', $tEvaluacion);
        $editForm->handleRequest($request);

        if ($editForm->isSubmitted() && $editForm->isValid()) {
            $this->getDoctrine()->getManager()->flush();
            $this->addFlash('mensaje', 'Se modificó la evaluación exitósamente.');

            return $this->redirectToRoute('tevaluacion_index');
        }

        return $this->render('tevaluacion/edit.html.twig', array(
            'tEvaluacion' => $tEvaluacion,
            'form' => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        ));
    }

//    /**
//     * Deletes a tEvaluacion entity.
//     *
//     * @Route("/{idEvaluacion}", name="tevaluacion_delete")
//     * @Method("DELETE")
//     */
//    public function deleteAction(Request $request, TEvaluacion $tEvaluacion)
//    {
//        $form = $this->createDeleteForm($tEvaluacion);
//        $form->handleRequest($request);
//
//        if ($form->isSubmitted() && $form->isValid()) {
//            $em = $this->getDoctrine()->getManager();
//            $em->remove($tEvaluacion);
//            $em->flush();
//        }
//
//        return $this->redirectToRoute('tevaluacion_index');
//    }

    /**
     * Creates a form to delete a tEvaluacion entity.
     *
     * @param TEvaluacion $tEvaluacion The tEvaluacion entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(TEvaluacion $tEvaluacion)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('tevaluacion_delete', array('id' => $tEvaluacion->getIdevaluacion())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }











    private function deleteUser($em, $tEvaluacion)
    {

        $em->remove($tEvaluacion);
        $em->flush();

        $message = 'La Evaluación ha sido eliminado exitósamente';

        $removed = 1;
        $alert = 'mensaje';


        return array('removed'=>$removed, 'message'=>$message, 'alert'=>$alert);
    }

    private function createCustomForm($id, $method, $route)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl($route, array('id'=>$id)))
            ->setMethod($method)
            ->getForm();
    }

    /**
     * @Route("/borrar/{id}", name="tevaluacion_delete")
     */
    public function deleteAction(Request $request, TEvaluacion $tEvaluacion)
    {
        $form = $this->createCustomForm($tEvaluacion->getIdEvaluacion(), 'DELETE', 'tevaluacion_delete');
        $form->handleRequest($request);
        $em = $this->getDoctrine()->getManager();

        if ($form->isSubmitted() && $form->isValid()) {

            if($request->isXMLHttpRequest())
            {
                $res = $this->deleteUser($em, $tEvaluacion);

                return new Response(
                    json_encode(array('removed'=>$res['removed'], 'message'=>$res['message'], )),
                    200,
                    array('Content-Type'=>'application/json')
                );
            }

            $res = $this->deleteUser($em, $tEvaluacion);

            $this->addFlash($res['alert'], $res['message']);

            return $this->redirectToRoute('tevaluacion_index');
        }
    }

}
