<?php

namespace AppBundle\Controller;

use AppBundle\Entity\TPeriodo;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;

use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Response;

use Symfony\Component\HttpFoundation\Request;

/**
 * Tperiodo controller.
 *
 * @Route("tperiodo")
 */
class TPeriodoController extends Controller
{
    /**
     * Lists all tPeriodo entities.
     *
     * @Route("/", name="tperiodo_index")
     * @Method("GET")
     */
    public function indexAction()
    {
        $em = $this->getDoctrine()->getManager();

        $tPeriodos = $em->getRepository('AppBundle:TPeriodo')->findAll();

	    $deleteFormAjax = $this->createCustomForm(':USER_ID', 'DELETE', 'tperiodo_delete');

        return $this->render('tperiodo/index.html.twig', array(
            'tPeriodos' => $tPeriodos,
            'delete_form_ajax' => $deleteFormAjax->createView(),
        ));
    }

    /**
     * Creates a new tPeriodo entity.
     *
     * @Route("/new", name="tperiodo_new")
     * @Method({"GET", "POST"})
     */
    public function newAction(Request $request)
    {
        $tPeriodo = new Tperiodo();
        $form = $this->createForm('AppBundle\Form\TPeriodoType', $tPeriodo);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($tPeriodo);
            $em->flush();

	        $this->addFlash( 'mensaje', 'Se agregó el periodo exitósamente.' );
            return $this->redirectToRoute('tperiodo_index');
        }

        return $this->render('tperiodo/new.html.twig', array(
            'tPeriodo' => $tPeriodo,
            'form' => $form->createView(),
        ));
    }



    /**
     * Displays a form to edit an existing tPeriodo entity.
     *
     * @Route("/{idPeriodo}/edit", name="tperiodo_edit")
     * @Method({"GET", "POST"})
     */
    public function editAction(Request $request, TPeriodo $tPeriodo)
    {
//        $deleteForm = $this->createDeleteForm($tPeriodo);
        $editForm = $this->createForm('AppBundle\Form\TPeriodoType', $tPeriodo);
        $editForm->handleRequest($request);

        if ($editForm->isSubmitted() && $editForm->isValid()) {
            $this->getDoctrine()->getManager()->flush();

	        $this->addFlash('mensaje', 'Se modificó datos del periodo exitósamente.');
            return $this->redirectToRoute('tperiodo_index');
        }

        return $this->render('tperiodo/edit.html.twig', array(
            'tPeriodo' => $tPeriodo,
            'form' => $editForm->createView(),
        ));
    }

//    /**
//     * Deletes a tPeriodo entity.
//     *
//     * @Route("/{idPeriodo}", name="tperiodo_delete")
//     * @Method("DELETE")
//     */
//    public function deleteAction(Request $request, TPeriodo $tPeriodo)
//    {
//        $form = $this->createDeleteForm($tPeriodo);
//        $form->handleRequest($request);
//
//        if ($form->isSubmitted() && $form->isValid()) {
//            $em = $this->getDoctrine()->getManager();
//            $em->remove($tPeriodo);
//            $em->flush();
//        }
//
//        return $this->redirectToRoute('tperiodo_index');
//    }

    /**
     * Creates a form to delete a tPeriodo entity.
     *
     * @param TPeriodo $tPeriodo The tPeriodo entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(TPeriodo $tPeriodo)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('tperiodo_delete', array('idPeriodo' => $tPeriodo->getIdperiodo())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }
	private function deleteUser($em, $tPeriodo)
	{

		$em->remove($tPeriodo);
		$em->flush();

		$message = 'El periodo ha sido eliminado exitósamente';

		$removed = 1;
		$alert = 'mensaje';


		return array('removed'=>$removed, 'message'=>$message, 'alert'=>$alert);
	}


	private function createCustomForm($id, $method, $route)
	{
		return $this->createFormBuilder()
		            ->setAction($this->generateUrl($route, array('id'=>$id)))
		            ->setMethod($method)
		            ->getForm();
	}



	/**
	 * @Route("/borrar/{id}", name="tperiodo_delete")
	 */
	public function deleteAction(Request $request, TPeriodo $tPeriodo)
	{
		//$form = $this->createDeleteForm($tPeriodo);
		$form = $this->createCustomForm($tPeriodo->getIdPeriodo(), 'DELETE', 'tperiodo_delete');
		$form->handleRequest($request);
		$em = $this->getDoctrine()->getManager();

		if ($form->isSubmitted() && $form->isValid()) {

			if($request->isXMLHttpRequest())
			{
				$res = $this->deleteUser($em, $tPeriodo);

				return new Response(
					json_encode(array('removed'=>$res['removed'], 'message'=>$res['message'], )),
					200,
					array('Content-Type'=>'application/json')
				);
			}

			$res = $this->deleteUser($em, $tPeriodo);

			$this->addFlash($res['alert'], $res['message']);

			return $this->redirectToRoute('tperiodo_index');
		}
	}
		
		
	}
