<?php

namespace AppBundle\Controller;

use AppBundle\Entity\TPregunta;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * TPregunta controller.
 *
 * @Route("tpregunta")
 */
class TPreguntaController extends Controller
{
    /**
     * Lists all TPregunta entities.
     *
     * @Route("/{idEvaluacion}/", name="tpregunta_index")
     * @Method({"GET", "POST"})
     */
    public function indexAction($idEvaluacion)
    {
        $em = $this->getDoctrine()->getManager();

        $tPreguntas = $em->getRepository('AppBundle:TPregunta')->findByIdEvaluacion($idEvaluacion);

        $deleteFormAjax = $this->createCustomForm(':USER_ID', 'DELETE', 'tpregunta_delete');
        return $this->render('tpregunta/index.html.twig', array(
            'tPreguntas' => $tPreguntas,
            'idEvaluacion' => $idEvaluacion,
            'delete_form_ajax' => $deleteFormAjax->createView(),
        ));
    }

    /**
     * Creates a new TPregunta entity.
     *
     * @Route("/{idEvaluacion}/new", name="tpregunta_new")
     * @Method({"GET", "POST"})
     */
    public function newAction(Request $request, $idEvaluacion)
    {
        $em = $this->getDoctrine()->getManager();
        $tEvaluacion = $em->getRepository('AppBundle:TEvaluacion')->find($idEvaluacion);

        $tPreguntasExistente = $em->getRepository('AppBundle:TUsuario')->findCantPreguntas($idEvaluacion);

        if($tEvaluacion->getNumeroPreguntas() >= intval($tPreguntasExistente[0]['cant']))
        {
            $TPregunta = new TPregunta();

            $form = $this->createForm('AppBundle\Form\TPreguntaType', $TPregunta);

            $form->handleRequest($request);

            if ($form->isSubmitted() && $form->isValid()) {
                $em = $this->getDoctrine()->getManager();
                $TPregunta->setIdEvaluacion($em->getRepository('AppBundle:TEvaluacion')->find($idEvaluacion));
                $TPregunta->setNumeroPregunta(intval($tPreguntasExistente[0]['cant'])+1);

                $em = $this->getDoctrine()->getManager();
                $em->persist($TPregunta);
                $em->flush();

                $this->addFlash('mensaje', 'Se agregó la pregunta exitósamente.');

                return $this->redirectToRoute('tpregunta_index', array('idEvaluacion' => $idEvaluacion));
            }

            return $this->render('tpregunta/new.html.twig', array(
                'TPregunta' => $TPregunta,
                'form' => $form->createView(),
            ));
        }
    }

    /**
     * Finds and displays a TPregunta entity.
     *
     * @Route("/{idPregunta}", name="tpregunta_show")
     * @Method("GET")
     */
    public function showAction(TPregunta $TPregunta)
    {
        $deleteForm = $this->createDeleteForm($TPregunta);

        return $this->render('tpregunta/show.html.twig', array(
            'TPregunta' => $TPregunta,
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Displays a form to edit an existing TPregunta entity.
     *
     * @Route("/{idPregunta}/edit", name="tpregunta_edit")
     * @Method({"GET", "POST"})
     */
    public function editAction(Request $request, TPregunta $TPregunta)
    {

        $editForm = $this->createForm('AppBundle\Form\TPreguntaType', $TPregunta);
        $editForm->handleRequest($request);

        if ($editForm->isSubmitted() && $editForm->isValid()) {
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('tpregunta_index', array('idEvaluacion' => $TPregunta->getIdEvaluacion()->getIdEvaluacion()));
        }

        return $this->render('tpregunta/edit.html.twig', array(
            'TPregunta' => $TPregunta,
            'form' => $editForm->createView(),

        ));
    }

//    /**
//     * Deletes a TPregunta entity.
//     *
//     * @Route("/{idPregunta}", name="tpregunta_delete")
//     * @Method("DELETE")
//     */
//    public function deleteAction(Request $request, TPregunta $TPregunta)
//    {
//        $form = $this->createDeleteForm($TPregunta);
//        $form->handleRequest($request);
//
//        if ($form->isSubmitted() && $form->isValid()) {
//            $em = $this->getDoctrine()->getManager();
//            $em->remove($TPregunta);
//            $em->flush();
//        }
//
//        return $this->redirectToRoute('tpregunta_index');
//    }

    /**
     * Creates a form to delete a TPregunta entity.
     *
     * @param TPregunta $TPregunta The TPregunta entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(TPregunta $TPregunta)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('tpregunta_delete', array('idPregunta' => $TPregunta->getIdpregunta())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }




















    private function deleteUser($em, $tPregunta)
    {

        $em->remove($tPregunta);
        $em->flush();

        $message = 'La Pregunta ha sido eliminado exitósamente';

        $removed = 1;
        $alert = 'mensaje';


        return array('removed'=>$removed, 'message'=>$message, 'alert'=>$alert);
    }

    private function createCustomForm($id, $method, $route)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl($route, array('id'=>$id)))
            ->setMethod($method)
            ->getForm();
    }

    /**
     * @Route("/borrar/{id}", name="tpregunta_delete")
     */
    public function deleteAction(Request $request, TPregunta $tPregunta)
    {
        $form = $this->createCustomForm($tPregunta->getIdPregunta(), 'DELETE', 'tpregunta_delete');
        $form->handleRequest($request);
        $em = $this->getDoctrine()->getManager();

        if ($form->isSubmitted() && $form->isValid()) {

            if($request->isXMLHttpRequest())
            {
                $res = $this->deleteUser($em, $tPregunta);

                return new Response(
                    json_encode(array('removed'=>$res['removed'], 'message'=>$res['message'], )),
                    200,
                    array('Content-Type'=>'application/json')
                );
            }

            $res = $this->deleteUser($em, $tPregunta);

            $this->addFlash($res['alert'], $res['message']);

            return $this->redirectToRoute('tpregunta_index');
        }
    }
}
