<?php

namespace AppBundle\Controller;

use AppBundle\Entity\TRespuesta;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Request;

/**
 * Trespuestum controller.
 *
 * @Route("trespuesta")
 */
class TRespuestaController extends Controller
{
    /**
     * Lists all tRespuestum entities.
     *
     * @Route("/{idCurso}/", name="trespuesta_index")
     * @Method("GET")
     */
    public function indexAction($idCurso)
    {
        $em = $this->getDoctrine()->getManager();
        $usuario = $this->getUser();

        $tPreguntas = $em->getRepository('AppBundle:TUsuario')->findEstudiantePreguntas($idCurso, $usuario);

//Grabando las respuestas del curso en el estudiante
        foreach ($tPreguntas as $tPregunta)
        {
//            var_dump($tPregunta['idPregunta']); exit();
            $tRespuesta = new TRespuesta();
            $tRespuesta->setIdPregunta($em->getRepository('AppBundle:TPregunta')->find($tPregunta['idPregunta']));
            $tRespuesta->setIdInscripcion($em->getRepository('AppBundle:TInscripcion')->find($tPregunta['idInscripcion']));
            $tRespuesta->setIdEvaluacion($em->getRepository('AppBundle:TEvaluacion')->find($tPregunta['idEvaluacion']));

            try {
                $em->persist($tRespuesta);
                $em->flush();
            }catch(\Doctrine\DBAL\DBALException $e) {
                $this->get('session')->getFlashBag()->add('status', 'EVALUACIÓN CONCLUIDA => No se puede volver a generar su Evaluación');
                return $this->redirect($this->generateUrl('tcontenido_index', array('idCurso' => $idCurso)));
            }

        }

        $tRespuestas = $em->getRepository('AppBundle:TUsuario')->findRespuestas($idCurso, $usuario, 1);

        return $this->render('trespuesta/index.html.twig', array(
            'tRespuestas' => $tRespuestas,
            'usuario' => $usuario,
        ));
    }

    /**
     * Creates a new tRespuestum entity.
     *
     * @Route("/new", name="trespuesta_new")
     * @Method({"GET", "POST"})
     */
    public function newAction(Request $request)
    {
        $tRespuesta = new Trespuestum();
        $form = $this->createForm('AppBundle\Form\TRespuestaType', $tRespuesta);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($tRespuesta);
            $em->flush();

            return $this->redirectToRoute('trespuesta_show', array('idRespuesta' => $tRespuesta->getIdrespuesta()));
        }

        return $this->render('trespuesta/new.html.twig', array(
            'tRespuestum' => $tRespuesta,
            'form' => $form->createView(),
        ));
    }

//    /**
//     * Finds and displays a tRespuestum entity.
//     *
//     * @Route("/{idRespuesta}", name="trespuesta_show")
//     * @Method("GET")
//     */
//    public function showAction(TRespuesta $tRespuesta)
//    {
//        $deleteForm = $this->createDeleteForm($tRespuesta);
//
//        return $this->render('trespuesta/show.html.twig', array(
//            'tRespuestum' => $tRespuesta,
//            'delete_form' => $deleteForm->createView(),
//        ));
//    }

    /**
     * Displays a form to edit an existing tRespuestum entity.
     *
     * @Route("/{idR}/{resp}/{correc}/{ptj}/{idInsc}/edit", name="trespuesta_edit", methods={"POST", "GET"})
     */
    public function editAction(Request $request, $idR, $resp, $correc, $ptj, $idInsc)
    {

        if($request->isXmlHttpRequest()) {

            if($correc != $resp)
                $ptj = 0;

            $Actualiza = $this->getDoctrine()->getManager();
            $Actualiza->getRepository( 'AppBundle:TUsuario' )->actualizaRespuesta($idR, $resp, $ptj);

            $Actualiza->getRepository( 'AppBundle:TUsuario' )->actualizaNota($idInsc);

            return new JsonResponse('Éxito');
        }
    }


    /**
     * @Route("/estado/{id}/{idEstado}/{idCurso}/{TipoNota}",  name="tinscripcion_estado", methods={"POST", "GET"})
     */
    public function estadoAction(Request $request, $id, $idEstado, $idCurso, $TipoNota)
    {


        if($request->isXmlHttpRequest()) {
            $usuario = $this->getUser()->getIdusuario();
            $fecha   = ( new \DateTime( "now" ) )->format( 'Y-m-d H:i:s' );

            if($TipoNota <> 9) {
                $em = $this->getDoctrine()->getManager();
                $id = $em->getRepository( 'AppBundle:TUsuario' )->findInscripcion( $id, $idCurso );
                $id = $id[0]['idInscripcion'];
            }

            $Estado = $this->getDoctrine()->getManager();
            $Estado->getRepository( 'AppBundle:TUsuario' )->actualizaEstado( $id, $idEstado, $usuario, $TipoNota);

//			No usamos esto porque cargaria la pagina de nuevo
//			return $this->redirectToRoute( 'tinscripcion_cursos', array( 'idCurso' => $idCurso ) );
            return new JsonResponse('Éxito');
        }
    }



    /**
     * Deletes a tRespuestum entity.
     *
     * @Route("/{idRespuesta}", name="trespuesta_delete")
     * @Method("DELETE")
     */
    public function deleteAction(Request $request, TRespuesta $tRespuesta)
    {
        $form = $this->createDeleteForm($tRespuesta);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->remove($tRespuesta);
            $em->flush();
        }
        var_dump($tRespuesta); exit();
        return $this->redirectToRoute('trespuesta_index');
    }

    /**
     * Creates a form to delete a tRespuestum entity.
     *
     * @param TRespuesta $tRespuesta The tRespuestum entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(TRespuesta $tRespuesta)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('trespuesta_delete', array('idRespuesta' => $tRespuesta->getIdrespuesta())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }
}
