<?php

namespace AppBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * TEstudiante
 *
 * @ORM\Table(name="t_estudiante", indexes={@ORM\Index(name="id_distrito", columns={"id_distrito"}), @ORM\Index(name="id_civil", columns={"id_civil"}), @ORM\Index(name="id_grado", columns={"id_grado"}), @ORM\Index(name="id_ocupacion", columns={"id_ocupacion"}), @ORM\Index(name="id_provincia", columns={"id_provincia"})})
 * @ORM\Entity
 * @UniqueEntity("carnet")
 */
class TEstudiante
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_estudiante", type="smallint", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idEstudiante;

    /**
     * @var string
     *
     * @ORM\Column(name="carnet", type="string", length=10, nullable=false)
     * @Assert\NotBlank()
     */
    private $carnet;

    /**
     * @var string
     *
     * @ORM\Column(name="paterno", type="string", length=50, nullable=true)
     */
    private $paterno;

    /**
     * @var string
     *
     * @ORM\Column(name="materno", type="string", length=50, nullable=true)
     */
    private $materno;

    /**
     * @var string
     *
     * @ORM\Column(name="nombre", type="string", length=60, nullable=false)
     * @Assert\NotBlank()
     */
    private $nombre;

    /**
     * @var string
     *
     * @ORM\Column(name="genero", type="string", length=1, nullable=false)
     * @Assert\NotBlank()
     */
    private $genero;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="nacimiento", type="date", nullable=false)
     * @Assert\NotBlank()
     */
    private $nacimiento;

    /**
     * @var string
     *
     * @ORM\Column(name="direccion", type="string", length=70, nullable=false)
     * @Assert\NotBlank()
     */
    private $direccion;

    /**
     * @var string
     *
     * @ORM\Column(name="zona", type="string", length=50, nullable=false)
     * @Assert\NotBlank()
     */
    private $zona;

    /**
     * @var integer
     *
     * @ORM\Column(name="telefono", type="integer", nullable=false)
     * @Assert\NotBlank()
     */
    private $telefono;

    /**
     * @var string
     *
     * @ORM\Column(name="correo", type="string", length=60, nullable=true)
     * @Assert\Email()
     */
    private $correo;

	/**
	 * @var \TDistrito
	 *
	 * @ORM\ManyToOne(targetEntity="TDistrito")
	 * @ORM\JoinColumns({
	 *   @ORM\JoinColumn(name="id_distrito", referencedColumnName="id_distrito")
	 * })
	 */
    private $idDistrito;

    /**
     * @var string
     *
     * @ORM\Column(name="observaciones", type="string", length=200, nullable=true)
     */
    private $observaciones;

    /**
     * @var string
     *
     * @ORM\Column(name="foto", type="string", length=80, nullable=true)
     */
    private $foto;


    /**
     * @var \TCivil
     *
     * @ORM\ManyToOne(targetEntity="TCivil")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_civil", referencedColumnName="id_civil")
     * })
     */
    private $idCivil;


    /**
     * @var \TGrado
     *
     * @ORM\ManyToOne(targetEntity="TGrado")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_grado", referencedColumnName="id_grado")
     * })
     */
    private $idGrado;

    /**
     * @var \TOcupacion
     *
     * @ORM\ManyToOne(targetEntity="TOcupacion")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_ocupacion", referencedColumnName="id_ocupacion")
     * })
     */
    private $idOcupacion;

    /**
     * @var \TProvincia
     *
     * @ORM\ManyToOne(targetEntity="TProvincia")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provincia", referencedColumnName="id_provincia")
     * })
     * @Assert\NotBlank()
     */
    private $idProvincia;

    /**
     * Set carnet
     *
     * @param string $carnet
     *
     * @return TEstudiante
     */
    public function setCarnet($carnet)
    {
        $this->carnet = $carnet;

        return $this;
    }

    /**
     * Get carnet
     *
     * @return string
     */
    public function getCarnet()
    {
        return $this->carnet;
    }

    /**
     * Set paterno
     *
     * @param string $paterno
     *
     * @return TEstudiante
     */
    public function setPaterno($paterno)
    {
        $this->paterno = $paterno;

        return $this;
    }

    /**
     * Get paterno
     *
     * @return string
     */
    public function getPaterno()
    {
        return $this->paterno;
    }

    /**
     * Set materno
     *
     * @param string $materno
     *
     * @return TEstudiante
     */
    public function setMaterno($materno)
    {
        $this->materno = $materno;

        return $this;
    }

    /**
     * Get materno
     *
     * @return string
     */
    public function getMaterno()
    {
        return $this->materno;
    }

    /**
     * Set nombre
     *
     * @param string $nombre
     *
     * @return TEstudiante
     */
    public function setNombre($nombre)
    {
        $this->nombre = $nombre;

        return $this;
    }

    /**
     * Get nombre
     *
     * @return string
     */
    public function getNombre()
    {
        return $this->nombre;
    }

    /**
     * Set genero
     *
     * @param string $genero
     *
     * @return TEstudiante
     */
    public function setGenero($genero)
    {
        $this->genero = $genero;

        return $this;
    }

    /**
     * Get genero
     *
     * @return string
     */
    public function getGenero()
    {
        return $this->genero;
    }

    /**
     * Set nacimiento
     *
     * @param \DateTime $nacimiento
     *
     * @return TEstudiante
     */
    public function setNacimiento($nacimiento)
    {
        $this->nacimiento = $nacimiento;

        return $this;
    }

    /**
     * Get nacimiento
     *
     * @return \DateTime
     */
    public function getNacimiento()
    {
        return $this->nacimiento;
    }

    /**
     * Set direccion
     *
     * @param string $direccion
     *
     * @return TEstudiante
     */
    public function setDireccion($direccion)
    {
        $this->direccion = $direccion;

        return $this;
    }

    /**
     * Get direccion
     *
     * @return string
     */
    public function getDireccion()
    {
        return $this->direccion;
    }

    /**
     * Set zona
     *
     * @param string $zona
     *
     * @return TEstudiante
     */
    public function setZona($zona)
    {
        $this->zona = $zona;

        return $this;
    }

    /**
     * Get zona
     *
     * @return string
     */
    public function getZona()
    {
        return $this->zona;
    }

    /**
     * Set telefono
     *
     * @param integer $telefono
     *
     * @return TEstudiante
     */
    public function setTelefono($telefono)
    {
        $this->telefono = $telefono;

        return $this;
    }

    /**
     * Get telefono
     *
     * @return integer
     */
    public function getTelefono()
    {
        return $this->telefono;
    }

    /**
     * Set correo
     *
     * @param string $correo
     *
     * @return TEstudiante
     */
    public function setCorreo($correo)
    {
        $this->correo = $correo;

        return $this;
    }

    /**
     * Get correo
     *
     * @return string
     */
    public function getCorreo()
    {
        return $this->correo;
    }

    /**
     * Set trabajo
     *
     * @param string $trabajo
     *
     * @return TEstudiante
     */
    public function setTrabajo($trabajo)
    {
        $this->trabajo = $trabajo;

        return $this;
    }

    /**
     * Get trabajo
     *
     * @return string
     */
    public function getTrabajo()
    {
        return $this->trabajo;
    }


    /**
     * Set montoApoyo
     *
     * @param integer $montoApoyo
     *
     * @return TEstudiante
     */
    public function setMontoApoyo($montoApoyo)
    {
        $this->montoApoyo = $montoApoyo;

        return $this;
    }

    /**
     * Get montoApoyo
     *
     * @return integer
     */
    public function getMontoApoyo()
    {
        return $this->montoApoyo;
    }

    /**
     * Set ingreso
     *
     * @param integer $ingreso
     *
     * @return TEstudiante
     */
    public function setIngreso($ingreso)
    {
        $this->ingreso = $ingreso;

        return $this;
    }

    /**
     * Get ingreso
     *
     * @return integer
     */
    public function getIngreso()
    {
        return $this->ingreso;
    }

    /**
     * Set violencia
     *
     * @param string $violencia
     *
     * @return TEstudiante
     */
    public function setViolencia($violencia)
    {
        $this->violencia = $violencia;

        return $this;
    }

    /**
     * Get violencia
     *
     * @return string
     */
    public function getViolencia()
    {
        return $this->violencia;
    }

    /**
     * Set victima
     *
     * @param string $victima
     *
     * @return TEstudiante
     */
    public function setVictima($victima)
    {
        $this->victima = $victima;

        return $this;
    }

    /**
     * Get victima
     *
     * @return string
     */
    public function getVictima()
    {
        return $this->victima;
    }

    /**
     * Set apoyoViolencia
     *
     * @param string $apoyoViolencia
     *
     * @return TEstudiante
     */
    public function setApoyoViolencia($apoyoViolencia)
    {
        $this->apoyoViolencia = $apoyoViolencia;

        return $this;
    }

    /**
     * Get apoyoViolencia
     *
     * @return string
     */
    public function getApoyoViolencia()
    {
        return $this->apoyoViolencia;
    }

    /**
     * Set hijos
     *
     * @param integer $hijos
     *
     * @return TEstudiante
     */
    public function setHijos($hijos)
    {
        $this->hijos = $hijos;

        return $this;
    }

    /**
     * Get hijos
     *
     * @return integer
     */
    public function getHijos()
    {
        return $this->hijos;
    }


	/**
	 * Set idProvincia2
	 *
	 * @param \AppBundle\Entity\TProvincia $idProvincia2
	 *
	 * @return TEstudiante
	 */
    public function setIdProvincia2($idProvincia2)
    {
        $this->idProvincia2 = $idProvincia2;

        return $this;
    }


	/**
	 * Get idProvincia2
	 *
	 * @return \AppBundle\Entity\TProvincia
	 */
    public function getIdProvincia2()
    {
        return $this->idProvincia2;
    }

	/**
	 * Set idDistrito
	 *
	 * @param \AppBundle\Entity\TDistrito $idDistrito
	 *
	 * @return TEstudiante
	 */
    public function setIdDistrito($idDistrito)
    {
        $this->idDistrito = $idDistrito;

        return $this;
    }

	/**
	 * Get idDistrito
	 *
	 * @return \AppBundle\Entity\TDistrito
	 */
    public function getIdDistrito()
    {
        return $this->idDistrito;
    }

    /**
     * Set observaciones
     *
     * @param string $observaciones
     *
     * @return TEstudiante
     */
    public function setObservaciones($observaciones)
    {
        $this->observaciones = $observaciones;

        return $this;
    }

    /**
     * Get observaciones
     *
     * @return string
     */
    public function getObservaciones()
    {
        return $this->observaciones;
    }

    /**
     * Set foto
     *
     * @param string $foto
     *
     * @return TEstudiante
     */
    public function setFoto($foto)
    {
        $this->foto = $foto;

        return $this;
    }

    /**
     * Get foto
     *
     * @return string
     */
    public function getFoto()
    {
        return $this->foto;
    }

    /**
     * Get idEstudiante
     *
     * @return integer
     */
    public function getIdEstudiante()
    {
        return $this->idEstudiante;
    }

    /**
     * Set idProvincia
     *
     * @param \AppBundle\Entity\TProvincia $idProvincia
     *
     * @return TEstudiante
     */
    public function setIdProvincia(\AppBundle\Entity\TProvincia $idProvincia = null)
    {
        $this->idProvincia = $idProvincia;

        return $this;
    }

    /**
     * Get idProvincia
     *
     * @return \AppBundle\Entity\TProvincia
     */
    public function getIdProvincia()
    {
        return $this->idProvincia;
    }



   /**
     * Set idOcupacion
     *
     * @param \AppBundle\Entity\TOcupacion $idOcupacion
     *
     * @return TEstudiante
     */
    public function setIdOcupacion(\AppBundle\Entity\TOcupacion $idOcupacion = null)
    {
        $this->idOcupacion = $idOcupacion;

        return $this;
    }

    /**
     * Get idOcupacion
     *
     * @return \AppBundle\Entity\TOcupacion
     */
    public function getIdOcupacion()
    {
        return $this->idOcupacion;
    }

    /**
     * Set idGrado
     *
     * @param \AppBundle\Entity\TGrado $idGrado
     *
     * @return TEstudiante
     */
    public function setIdGrado(\AppBundle\Entity\TGrado $idGrado = null)
    {
        $this->idGrado = $idGrado;

        return $this;
    }

    /**
     * Get idGrado
     *
     * @return \AppBundle\Entity\TGrado
     */
    public function getIdGrado()
    {
        return $this->idGrado;
    }

    /**
     * Set idCivil
     *
     * @param \AppBundle\Entity\TCivil $idCivil
     *
     * @return TEstudiante
     */
    public function setIdCivil(\AppBundle\Entity\TCivil $idCivil = null)
    {
        $this->idCivil = $idCivil;

        return $this;
    }

    /**
     * Get idCivil
     *
     * @return \AppBundle\Entity\TCivil
     */
    public function getIdCivil()
    {
        return $this->idCivil;
    }



	public function __toString()
	{
		return $this->getPaterno().' '.$this->getMaterno().' '.$this->getNombre() ;
	}

}
