<?php

namespace AppBundle\Form;

use AppBundle\Entity\TCarrera;
use AppBundle\Entity\TPeriodo;
use AppBundle\Entity\TTurno;
use AppBundle\Entity\TUsuario;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\Extension\Core\Type\FileType;
use Symfony\Component\Form\Extension\Core\Type\IntegerType;
use Symfony\Component\Form\Extension\Core\Type\DateType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;

class TCursoType extends AbstractType
{
    /**
     * {@inheritdoc}
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
	        ->add('fechaInicio',DateType::class, array(
		        'widget'=>'single_text',
		        'html5' => false,
		        'input' => 'datetime',
		        'label'=>'Fecha de Inicio',
		        'format'=>'dd/MM/yyyy',
		        'attr'=> ['class'=>'form-control mydatepicker', 'style' => 'margin-bottom:5px','placeholder'=>'dd/mm/yyyy']))
	        ->add('fechaFin',DateType::class, array(
		        'widget'=>'single_text',
		        'html5' => false,
		        'input' => 'datetime',
		        'label'=>'Fecha de Conclusión',
		        'format'=>'dd/MM/yyyy',
		        'attr'=> ['class'=>'form-control mydatepicker', 'style' => 'margin-bottom:5px','placeholder'=>'dd/mm/yyyy']))
	        ->add('paralelo',TextType::class, array(
		        'label'=>'Paralelo',
		        'attr'=>array('class'=>'form-control', 'style' => 'margin-bottom:10px', 'maxlength'=>1, 'onkeypress'=>'return controllet(event)')))
	        ->add('participantesProg',TextType::class, array(
		        'label'=>'Participantes Programados',
		        'attr'=>array('class'=>'form-control', 'style' => 'margin-bottom:10px', 'maxlength'=>3 )))

	        ->add('fechaIniEfectivo',DateType::class, array(
		        'widget'=>'single_text',
		        'html5' => false,
		        'input' => 'datetime',
		        'label'=>'Fecha Efectiva de Inicio',
		        'format'=>'dd/MM/yyyy',
		        'attr'=> ['class'=>'form-control mydatepicker', 'style' => 'margin-bottom:5px','placeholder'=>'dd/mm/yyyy']))
	        ->add('fechaFinEfectivo',DateType::class, array(
		        'widget'=>'single_text',
		        'html5' => false,
		        'input' => 'datetime',
		        'label'=>'Fecha Efectiva de Conclusión',
		        'format'=>'dd/MM/yyyy',
		        'attr'=> ['class'=>'form-control mydatepicker', 'style' => 'margin-bottom:5px','placeholder'=>'dd/mm/yyyy']))

//	        ->add('dias',TextType::class, array(
//		        'label'=>'Días programados',
//		        'attr'=>array('class'=>'form-control', 'style' => 'margin-bottom:10px', 'maxlength'=>100 )))

	        ->add('dias', ChoiceType::class, array(
		        'label'=>'Días programados',
		        'attr'=>array('class'=>'form-control', 'style' => 'margin-bottom:10px', 'maxlength'=>100 ),
		        'choices'   => array(
			        'Lunes'   => 'Lunes',
			        'Martes' => 'Martes',
			        'Miércoles'   => 'Miercoles',
			        'Jueves' => 'Jueves',
			        'Viernes'   => 'Viernes',
		        ),
		        'multiple'  => true,
//		        'mapped' => false,
	        ))


	        ->add('horas',TextType::class, array(
		        'label'=>'Periodos por día',
		        'attr'=>array('class'=>'form-control', 'style' => 'margin-bottom:10px', 'maxlength'=>1 )))



	        ->add('totalHoras',TextType::class, array(
		        'label'=>'Total Periodos programados',
		        'attr'=>array('class'=>'form-control', 'style' => 'margin-bottom:10px', 'maxlength'=>3 )))

	        ->add('horasClases',TextType::class, array(
		        'label'=>'Total Periodos Ejecutados',
		        'attr'=>array('class'=>'form-control', 'style' => 'margin-bottom:10px', 'maxlength'=>3 )))

	        ->add('idUsuario', EntityType::class, [
		        'label' => 'Profesor asignado',
		        'attr'=>array('class'=>'form-control', 'style' => 'margin-bottom:10px'),
		        'class' => TUsuario::class,
		        'placeholder' => '---- Escoge un profesor',
		        'query_builder' => function ($er) {
			        return $er->createQueryBuilder('p')
			                  ->select('p') // Entity Persona
//						->from(Persona::class, 'p')
			                  ->where('p.idRol=:tipoPersona ')
			                  ->setParameter('tipoPersona', '3')
						->orderBy('p.usnombres', 'ASC');
		        },
	        ])

	        ->add('idTurno', EntityType::class, [
		        'label' => 'Turno',
		        'class' => TTurno::class,
		        'choice_label' => 'descturno',
		        'placeholder' => 'Escoge un turno',])

	        ->add('idPeriodo', EntityType::class, [
		        'label' => 'Periodo Habilitado',
		        'attr'=>array('class'=>'form-control', 'style' => 'margin-bottom:10px'),
		        'class' => TPeriodo::class,
		        'placeholder' => '---- Escoge un periodo',
		        'query_builder' => function ($er) {
			        return $er->createQueryBuilder('p')
			                  ->select('p') // Entity Persona
//						->from(Persona::class, 'p')
			                  ->where('p.activo=:estado')
			                  ->setParameter('estado', '1')
			                  ->orderBy('p.idPeriodo', 'ASC');
		        },
	        ])

	        ->add('idCarrera', EntityType::class, [
		        'label' => 'Materia',
		        'class' => TCarrera::class,
		        'choice_label' => 'desccarrera',
		        'placeholder' => 'Escoge una Materia',])
	        ;
    }/**
     * {@inheritdoc}
     */
    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults(array(
            'data_class' => 'AppBundle\Entity\TCurso'
        ));
    }

    /**
     * {@inheritdoc}
     */
    public function getBlockPrefix()
    {
        return 'appbundle_tcurso';
    }


}
